@@ -62,11 +62,6 @@ local etcd_schema = {
             minimum = 1,
             description = "etcd connection timeout in seconds",
         },
-        use_grpc = {
-            type = "boolean",
-            -- TODO: set true by default in v3.2
-            default = false,
-        },
     },
     required = {"prefix", "host"}
 }
@@ -136,6 +131,10 @@ local config_schema = {
                         }
                     }
                 },
+                proxy_mode = {
+                    type = "string",
+                    enum = {"http", "stream", "http&stream"},
+                },
                 stream_proxy = {
                     type = "object",
                     properties = {
@@ -384,60 +383,23 @@ local deployment_schema = {
                     config_provider = {
                         enum = {"etcd"}
                     },
-                    conf_server = {
-                        properties = {
-                            listen = {
-                                type = "string",
-                                default = "0.0.0.0:9280",
-                            },
-                            cert = { type = "string" },
-                            cert_key = { type = "string" },
-                            client_ca_cert = { type = "string" },
-                        },
-                        required = {"cert", "cert_key"}
-                    },
                 },
-                required = {"config_provider", "conf_server"}
-            },
-            certs = {
-                properties = {
-                    cert = { type = "string" },
-                    cert_key = { type = "string" },
-                    trusted_ca_cert = { type = "string" },
-                },
-                dependencies = {
-                    cert = {
-                        required = {"cert_key"},
-                    },
-                },
-                default = {},
+                required = {"config_provider"}
             },
         },
         required = {"etcd", "role_control_plane"}
     },
     data_plane = {
         properties = {
+            etcd = etcd_schema,
             role_data_plane = {
                 properties = {
                     config_provider = {
-                        enum = {"control_plane", "yaml", "xds"}
+                        enum = {"etcd", "yaml", "xds"}
                     },
                 },
                 required = {"config_provider"}
             },
-            certs = {
-                properties = {
-                    cert = { type = "string" },
-                    cert_key = { type = "string" },
-                    trusted_ca_cert = { type = "string" },
-                },
-                dependencies = {
-                    cert = {
-                        required = {"cert_key"},
-                    },
-                },
-                default = {},
-            },
         },
         required = {"role_data_plane"}
     }
