@@ -54,6 +54,10 @@ local schema = {
             type = "string",
             default = "client_secret_basic"
         },
+        token_endpoint_auth_method = {
+            type = "string",
+            default = "client_secret_basic"
+        },
         bearer_only = {
             type = "boolean",
             default = false,
@@ -156,6 +160,10 @@ local schema = {
                     description = "Comma separated list of hosts that should not be proxied.",
                 }
             },
+        },
+        authorization_params = {
+            description = "Extra authorization params to the authorize endpoint",
+            type = "object"
         }
     },
     encrypt_fields = {"client_secret"},
